// Konfiguration für das Backend
export const BACKEND_URL = process.env.BACKEND_URL || 'http://localhost:5000';

// Standard Fetcher für SWR
export const fetcher = (url: string) => fetch(url).then((response) => response.json());

// Backend API Client für direkte API-Calls
export const backendFetcher = async (endpoint: string, options?: RequestInit) => {
  const url = `${BACKEND_URL}${endpoint}`;
  const response = await fetch(url, {
    ...options,
    headers: {
      'Content-Type': 'application/json',
      ...options?.headers,
    },
  });
  
  if (!response.ok) {
    throw new Error(`Backend API error: ${response.status} ${response.statusText}`);
  }
  
  return response.json();
};

// Backend API Wrapper mit spezifischen Endpunkten
export const backendApi = {
  // Drucker-Endpunkte
  printers: {
    getAll: () => backendFetcher('/api/printers'),
    getById: (id: string) => backendFetcher(`/api/printers/${id}`),
    create: (data: any) => backendFetcher('/api/printers', {
      method: 'POST',
      body: JSON.stringify(data),
    }),
    update: (id: string, data: any) => backendFetcher(`/api/printers/${id}`, {
      method: 'PUT',
      body: JSON.stringify(data),
    }),
    delete: (id: string) => backendFetcher(`/api/printers/${id}`, {
      method: 'DELETE',
    }),
  },
  
  // Druckaufträge-Endpunkte
  jobs: {
    getAll: () => backendFetcher('/api/jobs'),
    getById: (id: string) => backendFetcher(`/api/jobs/${id}`),
    create: (data: any) => backendFetcher('/api/jobs', {
      method: 'POST',
      body: JSON.stringify(data),
    }),
    abort: (id: string, reason: string) => backendFetcher(`/api/jobs/${id}/abort`, {
      method: 'POST',
      body: JSON.stringify({ reason }),
    }),
    finish: (id: string) => backendFetcher(`/api/jobs/${id}/finish`, {
      method: 'POST',
    }),
    extend: (id: string, minutes: number, hours: number) => backendFetcher(`/api/jobs/${id}/extend`, {
      method: 'POST',
      body: JSON.stringify({ minutes, hours }),
    }),
    updateComments: (id: string, comments: string) => backendFetcher(`/api/jobs/${id}/comments`, {
      method: 'PUT',
      body: JSON.stringify({ comments }),
    }),
    getRemainingTime: (id: string) => backendFetcher(`/api/job/${id}/remaining-time`),
  },
  
  // Statistiken-Endpunkt
  stats: {
    get: () => backendFetcher('/api/stats'),
  },
};
